@@ -2,7 +2,7 @@ package Test::ParallelSubtest;
 use strict;
 use warnings;
 
-our $VERSION = '0.03_01';
+our $VERSION = '0.01';
 
 use Test::Builder::Module;
 our @ISA    = qw(Test::Builder::Module);
@@ -14,6 +14,7 @@ our $_i_am_a_child = 0;
 our $MaxParallel = 4;
 
 use Carp;
+use POSIX ();
 use Sub::Prepend ();
 use TAP::Parser;
 use Test::Builder;
@@ -150,10 +151,7 @@ sub _child {
     );
 
     close $write_pipe;
-
-    no warnings 'redefine';
-    *Test::Builder::DESTROY = sub {};
-    exit(0);
+    POSIX::_exit(0);
 }
 
 sub bg_subtest_wait {
@@ -220,7 +218,7 @@ END
         return;
     }
 
-    if (defined $todo and $Test::Builder::VERSION >= 0.95_02) {
+    if (defined $todo and $Test::Builder::VERSION gt "0.95") {
         # Recent Test::Builder redirects the fail output to the todo
         # output for a todo subtest.
         $fail_dest = $todo_dest;
